# Generated by Django 5.2.10 on 2026-03-07 15:57

import django.db.models.deletion
import uuid
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_resaas', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='LayoutSetting',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('deleted_at', models.DateTimeField(blank=True, null=True)),
                ('estado', models.IntegerField(choices=[(0, 'Inativo'), (1, 'Ativo')], default=0, null=True)),
                ('primary', models.CharField(blank=True, default='', max_length=50, null=True)),
                ('secondary', models.CharField(blank=True, default='', max_length=50, null=True)),
                ('accent', models.CharField(blank=True, default='', max_length=50, null=True)),
                ('dark', models.CharField(blank=True, default='', max_length=50, null=True)),
                ('positive', models.CharField(blank=True, default='', max_length=50, null=True)),
                ('negative', models.CharField(blank=True, default='', max_length=50, null=True)),
                ('info', models.CharField(blank=True, default='', max_length=50, null=True)),
                ('warning', models.CharField(blank=True, default='', max_length=50, null=True)),
                ('created_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_created', to=settings.AUTH_USER_MODEL)),
                ('updated_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_updated', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'LayoutSetting',
                'verbose_name_plural': 'LayoutSettings',
                'permissions': (),
            },
        ),
        migrations.AddField(
            model_name='entidade',
            name='layout_settings',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='django_resaas.layoutsetting'),
        ),
        migrations.AddField(
            model_name='tipoentidade',
            name='layout_settings',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='django_resaas.layoutsetting'),
        ),
        migrations.CreateModel(
            name='Theme',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('deleted_at', models.DateTimeField(blank=True, null=True)),
                ('estado', models.IntegerField(choices=[(0, 'Inativo'), (1, 'Ativo')], default=0, null=True)),
                ('nome', models.CharField(max_length=100)),
                ('primary', models.CharField(default='#1976D2', max_length=7)),
                ('secondary', models.CharField(default='#26A69A', max_length=7)),
                ('accent', models.CharField(default='#9C27B0', max_length=7)),
                ('positive', models.CharField(default='#21BA45', max_length=7)),
                ('negative', models.CharField(default='#C10015', max_length=7)),
                ('warning', models.CharField(default='#F2C037', max_length=7)),
                ('info', models.CharField(default='#31CCEC', max_length=7)),
                ('dark', models.CharField(default='#1d1d1d', max_length=7)),
                ('created_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_created', to=settings.AUTH_USER_MODEL)),
                ('updated_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(class)s_updated', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'Theme',
                'verbose_name_plural': 'Theme',
                'permissions': (),
            },
        ),
        migrations.AddField(
            model_name='entidade',
            name='theme',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='django_resaas.theme'),
        ),
        migrations.AddField(
            model_name='tipoentidade',
            name='theme',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='django_resaas.theme'),
        ),
    ]
